@@ -1,16 +1,14 @@
 #!/usr/bin/perl
 
-use strict;
-use warnings;
+# ABSTRACT: Wrapper for Apache2 Action directive for running PSGI apps on shared hosting with FastCGI
 
 package Plack::App::Apache::ActionWrapper;
-{
-  $Plack::App::Apache::ActionWrapper::VERSION = '0.31.0';
-}
-use base 'Plack::Component';
-use File::Spec;
+our $VERSION = '0.01';
+use strict;
+use warnings;
+use base 'Plack::Middleware';
+
 
-# ABSTRACT: Wrapper for Apache2 Action directive for running PSGI apps on shared hosting with FastCGI
 
 
 sub call {
@@ -27,15 +25,10 @@ sub call {
               "You probably forgot to add the following lines to .htaccess:\n",
               "    Action psgi-handler /path/to/psgi.fcgi\n",
               "    AddHandler psgi-handler .psgi\n",
-              "(or your .psgi file has compilation errors)\n",
               $self->_get_debug_info($my_env),
             ],
         ];
     };
-    # Needed for Catalyst 5.9-based apps
-    if ( exists $env->{'REDIRECT_SCRIPT_URL'} ) {
-        $env->{'REDIRECT_URL'} = $env->{'REDIRECT_SCRIPT_URL'};
-    }
     return $app->($env);
 }
 
@@ -64,18 +57,21 @@ sub _resolve_app_filename {
 
     my $path_translated = $env->{'PATH_TRANSLATED'} || "";
 
-    # Split path into filesystem parts according to OS specific separator
-    my ($vol, $pt_dir) = File::Spec->splitpath($path_translated);
-    my @path_parts = File::Spec->splitdir($pt_dir);
-
     # Figure out which part of the path is actually the psgi file
-    while ( not -r $path_translated and @path_parts ) {
-        my $f = pop @path_parts;
-        $path_translated = File::Spec->catpath(
-            $vol, File::Spec->catdir(@path_parts), $f
-        );
+    my @path_parts = split(m{/}, $path_translated);
+    while ( ! -r join("/", @path_parts) ) {
+        last if @path_parts == 0; # Break out if we're at the end
+        pop @path_parts;
     }
-    return -r $path_translated && $path_translated;
+
+    # Return undef (that is, no app) if no path part was a readable file
+    return if @path_parts == 0;
+
+    # Execute the contents of the file and return last variable defined in it
+    my $psgi_file = join("/", @path_parts );
+
+    # Cache the app to allow persistent running
+    return $psgi_file;
 }
 
 sub _get_app {
@@ -103,7 +99,7 @@ sub _get_app {
     }
 
     # Return cached app
-    return $self->{'code_cache'}->{$app_filename};
+    return $self->{'code_cache'}->{$app_filename};        
 }
 
 sub _get_debug_info {
@@ -129,26 +125,21 @@ sub _get_debug_info {
 
 1;
 
-
-
+__END__
 =pod
 
-=encoding utf-8
-
 =head1 NAME
 
 Plack::App::Apache::ActionWrapper - Wrapper for Apache2 Action directive for running PSGI apps on shared hosting with FastCGI
 
 =head1 VERSION
 
-version 0.31.0
+version 0.01
 
 =head1 SYNOPSIS
 
     ------------- .htaccess -----------------
-    AddHandler fcgid-script .fcgi
-    # Enable this instead if server is using mod_fastcgi instead of mod_fcgid
-    #AddHandler fastcgi-script .fcgi
+    AddHandler fcgi-script .fcgi
     Action psgi-script /cgi-bin/psgi.fcgi
     AddHandler psgi-script .psgi
 
@@ -164,19 +155,6 @@ version 0.31.0
     use strict;
     use warnings;
 
-    # Some shared hosting providers don't even provide you
-    # with a pointer to your files
-    BEGIN {
-        $ENV{HOME} = '/home/someuser' unless $ENV{HOME};
-    }
-
-    # Enable this if you're unable to get output to STDERR
-    # in your normal log file
-    #use IO::Handle;
-    #close STDERR;
-    #open STDERR, ">>", "$ENV{HOME}/fcgi-error.log";
-    #STDERR->autoflush(1);
-
     # Change this line if you use local::lib or need
     # specific libraries loaded for your application
     use lib '/home/robin/perl5/lib/perl5';
@@ -185,8 +163,8 @@ version 0.31.0
     my $app = Plack::App::Apache::ActionWrapper->new->enable_debug->to_app;
 
     # Run the actual app
-    use Plack::Handler::FCGI;
-    Plack::Handler::FCGI->new->run($app);
+    use Plack::Server::FCGI;
+    Plack::Server::FCGI->new->run($app);
 
     1;
 
@@ -211,7 +189,7 @@ version 0.31.0
 
 =head1 DESCRIPTION
 
-The PSGI web application specification is awesome. Plack is awesome as well.
+The PSGI web application specification is awesome. Plack is awesome aswell.
 Running PSGI apps using plackup in development is super easy.
 
 But what do you do when you want to deploy your PSGI app on shared hosting?
@@ -222,7 +200,7 @@ So your shared hosting provider has provided you with FastCGI support to
 mitigate that problem. But because FastCGIExternalServer cannot be defined
 in .htaccess you can only run dynamic FastCGI applications.
 
-Your immediate reaction is to define C<AddHandler fcgid-script .psgi> in your
+Your immediate reaction is to define C<AddHandler fcgi-script .psgi> in your
 .htaccess and use plackup on the shebang line to run your PSGI app. But that
 doesn't work if you use local::lib, because @INC is not setup properly.
 
@@ -235,7 +213,7 @@ systems that provide it to diminish the memory usage.
 
 =head2 call
 
-The main handler that will be returned by the C<to_app> method inherited from L<Plack::Component>.
+The main handler that will be returned by the C<to_app> method inherited from L<Plack::Middleware>.
 
 =head2 enable_debug
 
@@ -249,134 +227,18 @@ Mutator to disable debug output if no path was found in PATH_TRANSLATED. Allows
 
 Accessor to determine if debug is enabled or not. Debug is disabled by default.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Plack::App::Apache::ActionWrapper
-
-=head2 Websites
-
-The following websites have more information about this module, and may be of help to you. As always,
-in addition to those websites please use your favorite search engine to discover more resources.
-
-=over 4
-
-=item *
-
-MetaCPAN
-
-A modern, open-source CPAN search engine, useful to view POD in HTML format.
-
-L<http://metacpan.org/release/Plack-App-Apache-ActionWrapper>
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Plack-App-Apache-ActionWrapper>
-
-=item *
-
-RT: CPAN's Bug Tracker
-
-The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Plack-App-Apache-ActionWrapper>
-
-=item *
-
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Plack-App-Apache-ActionWrapper>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Plack-App-Apache-ActionWrapper>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Plack-App-Apache-ActionWrapper>
-
-=item *
-
-CPANTS
-
-The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
-
-L<http://cpants.perl.org/dist/overview/Plack-App-Apache-ActionWrapper>
-
-=item *
-
-CPAN Testers
-
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
-
-L<http://www.cpantesters.org/distro/P/Plack-App-Apache-ActionWrapper>
-
-=item *
-
-CPAN Testers Matrix
-
-The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
-
-L<http://matrix.cpantesters.org/?dist=Plack-App-Apache-ActionWrapper>
-
-=item *
-
-CPAN Testers Dependencies
-
-The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
-
-L<http://deps.cpantesters.org/?module=Plack::App::Apache::ActionWrapper>
-
-=back
-
-=head2 Bugs / Feature Requests
-
-Please report any bugs or feature requests by email to C<bug-plack-app-apache-actionwrapper at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Plack-App-Apache-ActionWrapper>. You will be automatically notified of any
-progress on the request by the system.
-
-=head2 Source Code
-
-The code is open to the world, and available for you to hack on. Please feel free to browse it and play
-with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
-from your repository :)
-
-L<http://github.com/robinsmidsrod/Plack-App-Apache-ActionWrapper>
-
-  git clone git://github.com/robinsmidsrod/Plack-App-Apache-ActionWrapper.git
+=encoding utf8
 
 =head1 AUTHOR
 
-Robin Smidsrød <robin@smidsrod.no>
+  Robin Smidsrød <robin@smidsrod.no>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Robin Smidsrød.
+This software is copyright (c) 2009 by Robin Smidsrød.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
-__END__
-
